# Processor

Processor defines the actual processor for DataProcess. Processor can be either of a Job or a Shell script.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**job** | [**JobProcessor**](JobProcessor.md) |  | [optional] 
**pod_metadata** | [**PodMetadata**](PodMetadata.md) |  | [optional] 
**script** | [**ScriptProcessor**](ScriptProcessor.md) |  | [optional] 
**service_account_name** | **str** | ServiceAccountName defiens the serviceAccountName of the container | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


